package com.yunzhi.marketing.config;

import com.google.common.base.Predicate;
import io.swagger.annotations.ApiOperation;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import springfox.documentation.RequestHandler;
import springfox.documentation.builders.ApiInfoBuilder;
import springfox.documentation.builders.PathSelectors;
import springfox.documentation.service.ApiInfo;
import springfox.documentation.service.Contact;
import springfox.documentation.spi.DocumentationType;
import springfox.documentation.spring.web.plugins.Docket;
import springfox.documentation.swagger2.annotations.EnableSwagger2;

@Configuration
@EnableSwagger2
public class Swagger2Config {
        @Bean
        public Docket docket(){
            Predicate<RequestHandler> predicate = new Predicate<RequestHandler>() {
                @Override
                public boolean apply(RequestHandler input) {
                    //只有添加了ApiOperation注解的method才在API中显示
                    if (input.isAnnotatedWith(ApiOperation.class)) {
                        return true;
                    } else {
                        return false;
                    }
                }
            };
            return new Docket(DocumentationType.SWAGGER_2).groupName("docket").apiInfo(apiInfo()).select()
                    .apis(predicate)
                    .paths(PathSelectors.any()).build();
        }
        //构建api文档的详细信息函数
        private ApiInfo apiInfo(){
            return new ApiInfoBuilder()
                    //页面标题
                    .title("房产平台的 RESTful API")
                    //创建人
                    .contact(new Contact("房产平台","",""))
                    //版本号
                    .version("1.0")
                    //描述
                    .description("API 描述")
                    .build();
        }
}
