package com.yunzhi.marketing.xlk.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.yunzhi.marketing.base.ResponseBean;
import com.yunzhi.marketing.common.CommConstant;
import com.yunzhi.marketing.common.StringUtils;
import com.yunzhi.marketing.entity.TaRecommendCustomer;
import com.yunzhi.marketing.mapper.TaRecommendCustomerMapper;
import com.yunzhi.marketing.xlk.dto.*;
import com.yunzhi.marketing.xlk.entity.*;
import com.yunzhi.marketing.xlk.mapper.*;
import com.yunzhi.marketing.xlk.service.IChannelCustomerService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;

/**
 * <p>
 * 渠道报备客户表  服务实现类
 * </p>
 *
 * @author jobob
 * @since 2021-07-19
 */
@Service
public class ChannelCustomerServiceImpl extends ServiceImpl<ChannelCustomerMapper, ChannelCustomer> implements IChannelCustomerService {

    @Autowired
    private ChannelCustomerMapper channelCustomerMapper;

    @Autowired
    private TaRecommendCustomerMapper taRecommendCustomerMapper;

    @Autowired
    private CustomerVisitMapper customerVisitMapper;

    @Autowired
    private CustomerPreparatoryMapper customerPreparatoryMapper;

    @Autowired
    private CustomerSignatoryMapper customerSignatoryMapper;
    /**
     * 审核
     *
     * @param id
     * @param channelCustomerDTO
     * @return
     */
    @Override
    public ResponseBean auditCustomer(String id, ChannelCustomerDTO channelCustomerDTO) {
        ChannelCustomer customer = channelCustomerMapper.selectById(id);
        if ("fail".equals(channelCustomerDTO.getAuditResult())){
            // 审核不通过
            customer.setStatus("3");
            channelCustomerMapper.updateById(customer);
            return ResponseBean.success("审核成功");
        }

        // 审核通过 先查看在ta_recommend_customer 手机号是否存在
        LambdaQueryWrapper<TaRecommendCustomer> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(TaRecommendCustomer::getPhone,customer.getPhone());
        queryWrapper.eq(TaRecommendCustomer::getBuildingId,customer.getBuildingId());
        TaRecommendCustomer recommendCustomer = taRecommendCustomerMapper.selectOne(queryWrapper);
        if (null == recommendCustomer) {
            // 审核通过
            customer.setStatus("2");
            channelCustomerMapper.updateById(customer);
            // 进业务客户表
            TaRecommendCustomer taRecommendCustomer = new TaRecommendCustomer();
            taRecommendCustomer.setName(customer.getName());
            taRecommendCustomer.setPicture(customer.getPicture());
            taRecommendCustomer.setPhone(customer.getPhone());
            taRecommendCustomer.setSex(customer.getSex());
            taRecommendCustomer.setRecommendPerson(customer.getRecommendPerson());
            taRecommendCustomer.setBuildingId(customer.getBuildingId());
            taRecommendCustomer.setReportRecommendStatus(CommConstant.RECOMMENDED);
            taRecommendCustomer.setVerifyStatus(CommConstant.VERIFY_AGREE);
            taRecommendCustomer.setCreateDate(LocalDateTime.now());
            taRecommendCustomer.setReportDate(LocalDateTime.now());
            taRecommendCustomer.setOrgId(customer.getOrgId());
            taRecommendCustomer.setPersonId(customer.getPersonId());
            taRecommendCustomer.setEntryType(CommConstant.ENTRY_VERIFY);
            taRecommendCustomer.setStatus(CommConstant.CUSTOMER_REPORT);
            taRecommendCustomer.setRealtyConsultant(channelCustomerDTO.getRealtyConsultant());
            taRecommendCustomer.setCirculationTime(LocalDateTime.now());
            taRecommendCustomerMapper.insert(taRecommendCustomer);
            return ResponseBean.success("审核成功");
        }

        if (StringUtils.isEmpty(recommendCustomer.getRealtyConsultant()) &&
                (StringUtils.isEmpty(recommendCustomer.getRecommendPerson()) || recommendCustomer.getRecommendPerson().equals(customer.getRecommendPerson()))){
            // 审核通过
            customer.setStatus("2");
            channelCustomerMapper.updateById(customer);
            return ResponseBean.success("审核成功");
        }

        return ResponseBean.error("此客户是私客或已被报备", ResponseBean.ERROR_UNAVAILABLE);
    }

    /**
     * 驻场确认到访
     *
     * @param
     * @param params
     * @return
     */
    @Override
    public ResponseBean markingChannelCustomer(MarkingChannelCustomerDTO params) {
        // 渠道推荐的客户
        if ("report".equals(params.getType())) {
            ChannelCustomer customer = channelCustomerMapper.selectById(params.getId());
            // 审核通过 先查看在ta_recommend_customer 手机号是否存在
            LambdaQueryWrapper<TaRecommendCustomer> queryWrapper = new LambdaQueryWrapper<>();
            queryWrapper.eq(TaRecommendCustomer::getPhone,customer.getPhone());
            queryWrapper.eq(TaRecommendCustomer::getBuildingId,customer.getBuildingId());
            TaRecommendCustomer recommendCustomer = taRecommendCustomerMapper.selectOne(queryWrapper);
            if (null == recommendCustomer) {
                // 审核通过
                customer.setStatus("2");
                channelCustomerMapper.updateById(customer);
                // 进业务客户表
                TaRecommendCustomer taRecommendCustomer = new TaRecommendCustomer();
                taRecommendCustomer.setName(customer.getName());
                taRecommendCustomer.setPicture(customer.getPicture());
                taRecommendCustomer.setPhone(customer.getPhone());
                taRecommendCustomer.setSex(customer.getSex());
                taRecommendCustomer.setRecommendPerson(customer.getRecommendPerson());
                taRecommendCustomer.setBuildingId(customer.getBuildingId());
                taRecommendCustomer.setReportRecommendStatus(CommConstant.RECOMMENDED);
                taRecommendCustomer.setVerifyStatus(CommConstant.VERIFY_AGREE);
                taRecommendCustomer.setCreateDate(LocalDateTime.now());
                taRecommendCustomer.setReportDate(LocalDateTime.now());
                taRecommendCustomer.setOrgId(customer.getOrgId());
                taRecommendCustomer.setPersonId(customer.getPersonId());
                taRecommendCustomer.setEntryType(CommConstant.ENTRY_VERIFY);
                taRecommendCustomer.setStatus(CommConstant.CUSTOMER_VISITE);
                taRecommendCustomer.setRealtyConsultant(params.getRealtyConsultant());
                taRecommendCustomer.setCirculationTime(LocalDateTime.now());
                taRecommendCustomerMapper.insert(taRecommendCustomer);
            }else if (StringUtils.isEmpty(recommendCustomer.getRealtyConsultant()) &&
                    (StringUtils.isEmpty(recommendCustomer.getRecommendPerson()) || recommendCustomer.getRecommendPerson().equals(customer.getRecommendPerson()))){
                // 审核通过
                customer.setStatus("2");
                channelCustomerMapper.updateById(customer);

                // 修改状态为确认到访状态
                recommendCustomer.setRecommendPerson(customer.getRecommendPerson());
                recommendCustomer.setVerifyStatus(CommConstant.VERIFY_AGREE);
                recommendCustomer.setStatus(CommConstant.CUSTOMER_VISITE);
                recommendCustomer.setRealtyConsultant(params.getRealtyConsultant());
                recommendCustomer.setCirculationTime(LocalDateTime.now());
                taRecommendCustomerMapper.updateById(recommendCustomer);
            }
        }else if ("customer".equals(params.getType())) {
            // 置业顾问 经纪人推荐的客户
            TaRecommendCustomer taRecommendCustomer = taRecommendCustomerMapper.selectById(params.getId());
            taRecommendCustomer.setVerifyStatus(CommConstant.VERIFY_AGREE);
            taRecommendCustomer.setStatus(CommConstant.CUSTOMER_VISITE);
            taRecommendCustomer.setCirculationTime(LocalDateTime.now());
            taRecommendCustomerMapper.updateById(taRecommendCustomer);
        }else {
            return ResponseBean.error("请输入正确的类型参数", ResponseBean.ERROR_UNAVAILABLE);
        }

        // 保存到访单
        CustomerVisit customerVisit = params.getCustomerVisit();
        customerVisit.setCreateDate(LocalDateTime.now());
        customerVisitMapper.insert(customerVisit);

        return ResponseBean.success("审核成功");
    }

    /**
     * 驻场 无效报备
     *
     * @param params
     * @return
     */
    @Override
    public ResponseBean invalidCustomerUpdate(MarkingChannelCustomerDTO params) {// 渠道推荐的客户
        if ("channel".equals(params.getType())) {
            ChannelCustomer customer = channelCustomerMapper.selectById(params.getId());
            // 审核不通过 先查看在ta_recommend_customer 手机号是否存在
            LambdaQueryWrapper<TaRecommendCustomer> queryWrapper = new LambdaQueryWrapper<>();
            queryWrapper.eq(TaRecommendCustomer::getPhone,customer.getPhone());
            queryWrapper.eq(TaRecommendCustomer::getBuildingId,customer.getBuildingId());
            TaRecommendCustomer recommendCustomer = taRecommendCustomerMapper.selectOne(queryWrapper);
            if (null != recommendCustomer) {
                // 审核不通过
                recommendCustomer.setRecommendPerson(customer.getRecommendPerson());
                recommendCustomer.setVerifyStatus(CommConstant.VERIFY_AGREE);
                recommendCustomer.setStatus(CommConstant.CUSTOMER_VISITE);
                taRecommendCustomerMapper.updateById(recommendCustomer);

            }
            customer.setStatus("2");
            channelCustomerMapper.updateById(customer);
            return ResponseBean.success("审核成功");
        }else if ("customer".equals(params.getType())) {
            // 置业顾问 经纪人推荐的客户
            TaRecommendCustomer taRecommendCustomer = taRecommendCustomerMapper.selectById(params.getId());
            taRecommendCustomer.setVerifyStatus(CommConstant.VERIFY_DISAGREE);
            taRecommendCustomerMapper.updateById(taRecommendCustomer);
            return ResponseBean.success("审核成功");
        }
        return ResponseBean.error("无效操作", ResponseBean.ERROR_UNAVAILABLE);
    }

    @Override
    public IPage<ChannelCustomer> getProfileList(IPage<ChannelCustomer> pg,
                                                 Integer orgId,
                                                 String buildingId,
                                                 String name,
                                                 String phone,
                                                 String recommendPersonName,
                                                 String recommendPhone,
                                                 String status,String type) {
        return channelCustomerMapper.getProfileList(pg, orgId, buildingId, name, phone, recommendPersonName, recommendPhone, status, type);
    }

    /**
     * 驻场认筹
     *
     * @param params
     * @return
     */
    @Override
    public ResponseBean preparatoryCustomer(MarkingPreparatoryCustomerDTO params) {
        TaRecommendCustomer taRecommendCustomer = taRecommendCustomerMapper.selectById(params.getCustomerId());
        taRecommendCustomer.setStatus(CommConstant.CUSTOMER_PREPARATORY);
        taRecommendCustomerMapper.updateById(taRecommendCustomer);

        CustomerPreparatory customerPreparatory = params.getCustomerPreparatory();
        customerPreparatory.setCreateDate(LocalDateTime.now());
        customerPreparatoryMapper.insert(customerPreparatory);
        return ResponseBean.success("审核成功");
    }

    /**
     * 驻场结佣金
     *
     * @param params
     * @return
     */
    @Override
    public ResponseBean commissionCustomer(MarkingCommissionCustomerDTO params) {
        TaRecommendCustomer taRecommendCustomer = taRecommendCustomerMapper.selectById(params.getCustomerId());
        taRecommendCustomer.setStatus(CommConstant.CUSTOMER_COMMISSION);
        taRecommendCustomerMapper.updateById(taRecommendCustomer);
        return ResponseBean.success("审核成功");
    }

    /**
     * 驻场签约
     *
     * @param params
     * @return
     */
    @Override
    public ResponseBean signatoryCustomer(MarkingSignatoryCustomerDTO params) {
        TaRecommendCustomer taRecommendCustomer = taRecommendCustomerMapper.selectById(params.getCustomerId());
        taRecommendCustomer.setStatus(CommConstant.CUSTOMER_SIGNED);
        taRecommendCustomerMapper.updateById(taRecommendCustomer);

        CustomerSignatory customerSignatory = params.getCustomerSignatory();
        customerSignatory.setCreateDate(LocalDateTime.now());
        customerSignatoryMapper.insert(customerSignatory);
        return ResponseBean.success("审核成功");
    }
}
